@@ -1,6 +1,7 @@
 from unittest import TestCase
 
-import tree_sitter, tree_sitter_LOWER_PARSER_NAME
+import tree_sitter
+import tree_sitter_LOWER_PARSER_NAME
 
 
 class TestLanguage(TestCase):
@@ -8,4 +9,4 @@ class TestLanguage(TestCase):
         try:
             tree_sitter.Language(tree_sitter_LOWER_PARSER_NAME.language())
         except Exception:
-            self.fail("Error loading CAMEL_PARSER_NAME grammar")
+            self.fail("Error loading TITLE_PARSER_NAME grammar")
